@@ -1333,7 +1333,8 @@ class Members extends AdminController
 				'action_browse' => (isset($element->browse) ? (int) $element->browse : 0),
 				'min'           => (isset($element->field_options->min) ? (int) $element->field_options->min : 0),
 				'max'           => (isset($element->field_options->max) ? (int) $element->field_options->max : 0),
-				'default_value' => (isset($element->field_options->value) ? (string) $element->field_options->value : '')
+				'default_value' => (isset($element->field_options->value) ? (string) $element->field_options->value : ''),
+				'placeholder'   => (isset($element->field_options->placeholder) ? (string) $element->field_options->placeholder : '')
 			));
 
 			if ($field->get('type') == 'dropdown')
